@@ -22,9 +22,10 @@
 
 #include "incidencedefaults.h"
 #include "alarmpresets.h"
+#include "incidenceeditor_debug.h"
 
 #include <CalendarSupport/KCalPrefs>
-#include <akonadi/calendar/calendarsettings.h>
+#include <akonadi/calendar/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
 
 #include <KContacts/Addressee>
 
@@ -34,9 +35,9 @@
 #include <KCalCore/Alarm>
 
 #include <KEmailAddress>
+
 #include <KIO/Job>
 #include <KIO/StoredTransferJob>
-#include "incidenceeditor_debug.h"
 #include <KLocalizedString>
 
 #include <QUrl>
@@ -60,8 +61,8 @@ public:
     QStringList mEmails;
     QString mGroupWareDomain;
     KCalCore::Incidence::Ptr mRelatedIncidence;
-    KDateTime mStartDt;
-    KDateTime mEndDt;
+    QDateTime mStartDt;
+    QDateTime mEndDt;
     bool mCleanupTemporaryFiles;
 
     /// Methods
@@ -139,11 +140,11 @@ KCalCore::Attendee::Ptr IncidenceDefaultsPrivate::organizerAsAttendee(
 
 void IncidenceDefaultsPrivate::eventDefaults(const KCalCore::Event::Ptr &event) const
 {
-    KDateTime startDT;
+    QDateTime startDT;
     if (mStartDt.isValid()) {
         startDT = mStartDt;
     } else {
-        startDT = KDateTime::currentLocalDateTime();
+        startDT = QDateTime::currentDateTime();
 
         if (KCalPrefs::instance()->startTime().isValid()) {
             startDT.setTime(KCalPrefs::instance()->startTime().time());
@@ -151,10 +152,10 @@ void IncidenceDefaultsPrivate::eventDefaults(const KCalCore::Event::Ptr &event)
     }
 
     const QTime defaultDurationTime = KCalPrefs::instance()->defaultDuration().time();
-    const int defaultDuration = defaultDurationTime.hour() * 3600
-                                +defaultDurationTime.minute() * 60;
+    const int defaultDuration = (defaultDurationTime.hour() * 3600)
+                                +(defaultDurationTime.minute() * 60);
 
-    const KDateTime endDT = mEndDt.isValid() ? mEndDt : startDT.addSecs(defaultDuration);
+    const QDateTime endDT = mEndDt.isValid() ? mEndDt : startDT.addSecs(defaultDuration);
 
     event->setDtStart(startDT);
     event->setDtEnd(endDT);
@@ -167,7 +168,7 @@ void IncidenceDefaultsPrivate::eventDefaults(const KCalCore::Event::Ptr &event)
 
 void IncidenceDefaultsPrivate::journalDefaults(const KCalCore::Journal::Ptr &journal) const
 {
-    const KDateTime startDT = mStartDt.isValid() ? mStartDt : KDateTime::currentLocalDateTime();
+    const QDateTime startDT = mStartDt.isValid() ? mStartDt : QDateTime::currentDateTime();
     journal->setDtStart(startDT);
     journal->setAllDay(true);
 }
@@ -185,21 +186,21 @@ void IncidenceDefaultsPrivate::todoDefaults(const KCalCore::Todo::Ptr &todo) con
         todo->setDtDue(relatedTodo->dtDue(true), true /** first */);
         todo->setAllDay(relatedTodo->allDay());
     } else if (relatedTodo) {
-        todo->setDtDue(KDateTime());
+        todo->setDtDue(QDateTime());
     } else {
-        todo->setDtDue(KDateTime::currentLocalDateTime().addDays(1), true /** first */);
+        todo->setDtDue(QDateTime::currentDateTime().addDays(1), true /** first */);
     }
 
     if (mStartDt.isValid()) {
         todo->setDtStart(mStartDt);
     } else if (relatedTodo && !relatedTodo->hasStartDate()) {
-        todo->setDtStart(KDateTime());
+        todo->setDtStart(QDateTime());
     } else if (relatedTodo && relatedTodo->hasStartDate()
                && relatedTodo->dtStart() <= todo->dtDue()) {
         todo->setDtStart(relatedTodo->dtStart());
         todo->setAllDay(relatedTodo->allDay());
-    } else if (!mEndDt.isValid() || (KDateTime::currentLocalDateTime() < mEndDt)) {
-        todo->setDtStart(KDateTime::currentLocalDateTime());
+    } else if (!mEndDt.isValid() || (QDateTime::currentDateTime() < mEndDt)) {
+        todo->setDtStart(QDateTime::currentDateTime());
     } else {
         todo->setDtStart(mEndDt.addDays(-1));
     }
@@ -245,9 +246,7 @@ IncidenceDefaults &IncidenceDefaults::operator=(const IncidenceDefaults &other)
     return *this;
 }
 
-void IncidenceDefaults::setAttachments(const QStringList &attachments,
-                                       const QStringList &attachmentMimetypes,
-                                       const QStringList &attachmentLabels, bool inlineAttachment)
+void IncidenceDefaults::setAttachments(const QStringList &attachments, const QStringList &attachmentMimetypes, const QStringList &attachmentLabels, bool inlineAttachment)
 {
     Q_D(IncidenceDefaults);
     d->mAttachments.clear();
@@ -338,13 +337,13 @@ void IncidenceDefaults::setRelatedIncidence(const KCalCore::Incidence::Ptr &inci
     d->mRelatedIncidence = incidence;
 }
 
-void IncidenceDefaults::setStartDateTime(const KDateTime &startDT)
+void IncidenceDefaults::setStartDateTime(const QDateTime &startDT)
 {
     Q_D(IncidenceDefaults);
     d->mStartDt = startDT;
 }
 
-void IncidenceDefaults::setEndDateTime(const KDateTime &endDT)
+void IncidenceDefaults::setEndDateTime(const QDateTime &endDT)
 {
     Q_D(IncidenceDefaults);
     d->mEndDt = endDT;
